pkgsrc-WIP-changes archive

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index][Old Index]

rust183: replicate fix from rust184 to pick up external LLVM.



Module Name:	pkgsrc-wip
Committed By:	Havard Eidnes <he%NetBSD.org@localhost>
Pushed By:	he
Date:		Mon Feb 3 22:34:17 2025 +0000
Changeset:	dbfe8ea2642ccd91b5718bf6484bb01fa27ab181

Modified Files:
	rust183/distinfo
	rust183/patches/patch-src_bootstrap_src_core_builder.rs

Log Message:
rust183: replicate fix from rust184 to pick up external LLVM.

To see a diff of this commit:
https://wip.pkgsrc.org/cgi-bin/gitweb.cgi?p=pkgsrc-wip.git;a=commitdiff;h=dbfe8ea2642ccd91b5718bf6484bb01fa27ab181

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

diffstat:
 rust183/distinfo                                        |  2 +-
 rust183/patches/patch-src_bootstrap_src_core_builder.rs | 10 ++++------
 2 files changed, 5 insertions(+), 7 deletions(-)

diffs:
diff --git a/rust183/distinfo b/rust183/distinfo
index b991081044..fff6610ea3 100644
--- a/rust183/distinfo
+++ b/rust183/distinfo
@@ -124,7 +124,7 @@ SHA1 (patch-library_stdarch_crates_std__detect_tests_cpu-detection.rs) = 97c3ad8
 SHA1 (patch-src_bootstrap_bootstrap.py) = 150a5a7e057de9edbf96f3c387207fda8ba750f9
 SHA1 (patch-src_bootstrap_src_core_build__steps_compile.rs) = e928203ed4734c93cc33c5a3f7879cf18dcecc83
 SHA1 (patch-src_bootstrap_src_core_build__steps_install.rs) = cc6558df42c9c9ac28fdb2ff180bdaa7f22ce816
-SHA1 (patch-src_bootstrap_src_core_builder.rs) = 6d996c1b82755a5cf81761dc65c88572641aec10
+SHA1 (patch-src_bootstrap_src_core_builder.rs) = 5e630630b135541e65c0b7f166ed38570c8cfaf7
 SHA1 (patch-src_bootstrap_src_lib.rs) = d29bc3c0b335d5e788eecbb02fc08966beef0fb1
 SHA1 (patch-src_llvm-project_llvm_CMakeLists.txt) = 7abfabb6ec70df229a69355f8c76825610165c37
 SHA1 (patch-src_llvm-project_llvm_cmake_modules_AddLLVM.cmake) = e1b2eb2f0b3cf1cf87b443656ae306b3242f6b12
diff --git a/rust183/patches/patch-src_bootstrap_src_core_builder.rs b/rust183/patches/patch-src_bootstrap_src_core_builder.rs
index 9ed35e5c17..47c0d2e122 100644
--- a/rust183/patches/patch-src_bootstrap_src_core_builder.rs
+++ b/rust183/patches/patch-src_bootstrap_src_core_builder.rs
@@ -1,6 +1,6 @@
 $NetBSD: patch-src_bootstrap_src_core_builder.rs,v 1.5 2024/07/27 02:35:24 tnn Exp $
 
-Find external libunwind on Linux.
+Find external libunwind and libLLVM on pkgsrc (not just Linux).
 Use @PREFIX@ in rpath.
 
 Also, follow up on
@@ -30,14 +30,12 @@ which should fix the cross-compile failure.
                      let not_supported = error
                          .lines()
                          .any(|line| line.contains("unsupported crate type `proc-macro`"));
-@@ -2262,6 +2266,11 @@ impl<'a> Builder<'a> {
+@@ -2262,6 +2266,9 @@ impl<'a> Builder<'a> {
              rustdocflags.arg("--cfg=parallel_compiler");
          }
  
-+	// added for pkgsrc libunwind
-+	if target.contains("linux") {
-+		rustflags.arg("-Clink-args=-Wl,-rpath,@PREFIX@/lib,-L@PREFIX@/lib");
-+	}
++	// added for pkgsrc libunwind and LLVM
++	rustflags.arg("-Clink-args=-Wl,-rpath,@PREFIX@/lib,-L@PREFIX@/lib");
 +
          Cargo {
              command: cargo,


Home | Main Index | Thread Index | Old Index